Computer

Input
Input decomposition will appear here...
Activity
Output
▸ History (0)
Responses will appear here...
▸ History (0)
Blueprint will appear here...
Files created during this session will appear here...
Your to-do items will appear here...
⬆ Upload
Upload a CSV or XLSX to create a table, or select one from the list.
CSV XLSX

Persistent insights will appear here...
Visual rendering will appear here...
File Preview
Choose Theme
Built-in Themes
Custom Themes
⬆ Upload
No custom themes yet. Download the template, customize it, and upload!
Choose Model
Loading models...
Use Your Own API Key
Use my own key
Provider
Model API Key
Your key is stored only in this browser. It is never saved on the server.
Choose Persona
Loading personas...
Approval Required
Choose Playbook
Loading playbooks...
Session Settings
Session Name Description Instructions
Read Folders
Active folders
Browse & add folder
Loading...
-
Active Google Drive folders
Browse & add folder
Loading...
My Drive
LLM Stream